from setuptools import setup, find_packages

setup(
       name='cxk',
       version='0.1145',
       packages=find_packages(),
       description='cxk',
       author='hidrag',
       author_email='114514@baidu.com',
   )
